[eGroupWare-svn] r55883 - /trunk/mail/js/app.js

[email protected]
Newsgroups gmane.comp.web.egroupware.cvs
Message-ID <[email protected]>
Author: hnategh
Date: Wed Apr 27 15:03:52 2016
New Revision: 55883

URL: http://svn.stylite.de/viewvc/egroupware?rev=55883&view=rev
Log:
Fix mail seen label does not work on mobile template

Modified:
    trunk/mail/js/app.js

Modified: trunk/mail/js/app.js
URL: http://svn.stylite.de/viewvc/egroupware/trunk/mail/js/app.js?rev=55883&r1=55882&r2=55883&view=diff
==============================================================================
--- trunk/mail/js/app.js (original)
+++ trunk/mail/js/app.js Wed Apr 27 15:03:52 2016
@@ -918,54 +918,58 @@
 				IframeHandle.set_src('about:blank');
 				this.mail_disablePreviewArea(true);
 			}
-			return;
-		}
-
-		// Widget ID:data key map of widgets we can directly set from cached data
-		var data_widgets = {
-			'previewFromAddress':	'fromaddress',
-			'previewDate':			'date',
-			'previewSubject':		'subject'
-		};
-
-		// Set widget values from cached data
-		for(var id in data_widgets)
-		{
-			var widget = this.et2.getWidgetById(id);
-			if(widget == null) continue;
-			widget.set_value(dataElem.data[data_widgets[id]] || "");
-		}
-
-		// Blank first, so we don't show previous email while loading
-		var IframeHandle = this.et2.getWidgetById('messageIFRAME');
-		IframeHandle.set_src('about:blank');
-
-		// show iframe, in case we hide it from mailvelopes one and remove that
-		jQuery(IframeHandle.getDOMNode()).show()
-			.next(this.mailvelope_iframe_selector).remove();
-
-		// Set up additional content that can be expanded.
-		// We add a new URL widget for each address, so they get all the UI
-		// TO addresses have the first one split out, not all together
-		// list of keys:
-		var expand_content = [
-			{build_children: true, data_one: 'toaddress', data: 'additionaltoaddress', widget: 'additionalToAddress', line: 'mailPreviewHeadersTo'},
-			{build_children: true, data: 'ccaddress', widget: 'additionalCCAddress', line: 'mailPreviewHeadersCC'},
-			{build_children: false, data: 'attachmentsBlock', widget:'previewAttachmentArea', line: 'mailPreviewHeadersAttachments'}
-		];
-
-		dataElem = this.url_email_expandOnClick(expand_content,dataElem);
-
-
-		// Update the internal list of selected mails, if needed
-		if(this.mail_selectedMails.indexOf(_id) < 0)
-		{
-			this.mail_selectedMails.push(_id);
-		}
-		this.mail_disablePreviewArea(false);
-
-		// Request email body from server
-		IframeHandle.set_src(egw.link('/index.php',{menuaction:'mail.mail_ui.loadEmailBody',_messageID:_id}));
+			if (!egwIsMobile())return;
+		}
+		// Not applied to mobile preview
+		if (!egwIsMobile())
+		{
+
+			// Widget ID:data key map of widgets we can directly set from cached data
+			var data_widgets = {
+				'previewFromAddress':	'fromaddress',
+				'previewDate':			'date',
+				'previewSubject':		'subject'
+			};
+
+			// Set widget values from cached data
+			for(var id in data_widgets)
+			{
+				var widget = this.et2.getWidgetById(id);
+				if(widget == null) continue;
+				widget.set_value(dataElem.data[data_widgets[id]] || "");
+			}
+
+			// Blank first, so we don't show previous email while loading
+			var IframeHandle = this.et2.getWidgetById('messageIFRAME');
+			IframeHandle.set_src('about:blank');
+
+			// show iframe, in case we hide it from mailvelopes one and remove that
+			jQuery(IframeHandle.getDOMNode()).show()
+				.next(this.mailvelope_iframe_selector).remove();
+
+			// Set up additional content that can be expanded.
+			// We add a new URL widget for each address, so they get all the UI
+			// TO addresses have the first one split out, not all together
+			// list of keys:
+			var expand_content = [
+				{build_children: true, data_one: 'toaddress', data: 'additionaltoaddress', widget: 'additionalToAddress', line: 'mailPreviewHeadersTo'},
+				{build_children: true, data: 'ccaddress', widget: 'additionalCCAddress', line: 'mailPreviewHeadersCC'},
+				{build_children: false, data: 'attachmentsBlock', widget:'previewAttachmentArea', line: 'mailPreviewHeadersAttachments'}
+			];
+
+			dataElem = this.url_email_expandOnClick(expand_content,dataElem);
+
+
+			// Update the internal list of selected mails, if needed
+			if(this.mail_selectedMails.indexOf(_id) < 0)
+			{
+				this.mail_selectedMails.push(_id);
+			}
+			this.mail_disablePreviewArea(false);
+
+			// Request email body from server
+			IframeHandle.set_src(egw.link('/index.php',{menuaction:'mail.mail_ui.loadEmailBody',_messageID:_id}));
+		}
 
 		var messages = {};
 		messages['msg'] = [_id];


------------------------------------------------------------------------------
Find and fix application performance issues faster with Applications Manager
Applications Manager provides deep performance insights into multiple tiers of
your business applications. It resolves application problems quickly and
reduces your MTTR. Get your free trial!
https://ad.doubleclick.net/ddm/clk/302982198;130105516;z
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.